Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(829)

Unified Diff: app/gfx/skia_utils_gtk.h

Issue 660063: Move skia_utils_gtk.cc/.h to app/gfx/ directory. (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: fixes comments Created 10 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « app/app_base.gypi ('k') | app/gfx/skia_utils_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: app/gfx/skia_utils_gtk.h
===================================================================
--- app/gfx/skia_utils_gtk.h (revision 39851)
+++ app/gfx/skia_utils_gtk.h (working copy)
@@ -1,22 +1,22 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-
-#ifndef SKIA_EXT_SKIA_UTILS_GTK_H_
-#define SKIA_EXT_SKIA_UTILS_GTK_H_
-
-#include "third_party/skia/include/core/SkColor.h"
-
-typedef struct _GdkColor GdkColor;
-
-namespace skia {
-
-// Converts GdkColors to the ARGB layout Skia expects.
-SkColor GdkColorToSkColor(GdkColor color);
-
-// Converts ARGB to GdkColor.
-GdkColor SkColorToGdkColor(SkColor color);
-
-} // namespace skia
-
-#endif // SKIA_EXT_SKIA_UTILS_GTK_H_
+// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#ifndef APP_GFX_SKIA_UTILS_GTK_H_
+#define APP_GFX_SKIA_UTILS_GTK_H_
+
+#include "third_party/skia/include/core/SkColor.h"
+
+typedef struct _GdkColor GdkColor;
+
+namespace gfx {
+
+// Converts GdkColors to the ARGB layout Skia expects.
+SkColor GdkColorToSkColor(GdkColor color);
+
+// Converts ARGB to GdkColor.
+GdkColor SkColorToGdkColor(SkColor color);
+
+} // namespace gfx
+
+#endif // APP_GFX_SKIA_UTILS_GTK_H_
« no previous file with comments | « app/app_base.gypi ('k') | app/gfx/skia_utils_gtk.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698